aboutsummaryrefslogtreecommitdiff
path: root/gcc/emit-rtl.c
diff options
context:
space:
mode:
authorJan Hubicka <jh@suse.cz>2003-06-08 21:35:54 +0200
committerJan Hubicka <hubicka@gcc.gnu.org>2003-06-08 19:35:54 +0000
commit0435312e3890ead4503ac3d1c83afc556b39dc39 (patch)
tree852a6d09fbb544c05a647e6acf28fdbf9741a19d /gcc/emit-rtl.c
parent5d39821d113805e918072e3bb6c91a28a6f66188 (diff)
downloadgcc-0435312e3890ead4503ac3d1c83afc556b39dc39.zip
gcc-0435312e3890ead4503ac3d1c83afc556b39dc39.tar.gz
gcc-0435312e3890ead4503ac3d1c83afc556b39dc39.tar.bz2
cfglayout.c (insn_scope): New static function
* cfglayout.c (insn_scope): New static function (block_locators_*, line_locators*, file_locators*): New static varrays. (scope_to_insns_initialize): Use them. (insn_line, insn_file): New functions. (scope_to_insns_finalize): Use insn_scope. (prologue_locator, epilogue_locator): New global variables. * emit-rt.c (try_split, make_insn_raw, make_jump_insn_raw, make_call_insn_raw, emit_copy_of_insn_after): Use locators. (emit_insn_after_scope, emit_insn_before_scope emit_jump_insn_after_scope, emit_jump_insn_before_scope emit_call_insn_after_scope, emit_call_insn_before_scope): Rename to... (emit_insn_after_setloc, emit_insn_before_setloc emit_jump_insn_after_setloc, emit_jump_insn_before_setloc emit_call_insn_after_setloc, emit_call_insn_before_setloc): ... these; use locators. * final.c (notice_source_line): Use locators. (final_start_function): Set initial source file and line. (final_scan_insn): Use locators. * ifcvt.c (noce_try_store_flag, noce_try_store_flag_constants, noce_try_addcc, noce_try_store_flag_mask, noce_try_cmove, noce_try_cmove_arith, noce_try_minmax, noce_try_abs, noce_process_if_block, find_cond_trap): Likewise. * integrate.c (copy_insn_list): Likewise. * jump.c (duplicate_loop_exit_test): LIkewise. * print-rtl.c (print_rtx): Print locators. * recog.c (peephole2_optimize): Likewise. * rtl.h (INSN_SCOPE): Remove. (emit_insn_after_scope, emit_insn_before_scope emit_jump_insn_after_scope, emit_jump_insn_before_scope emit_call_insn_after_scope, emit_call_insn_before_scope): Rename to... (emit_insn_after_setloc, emit_insn_before_setloc emit_jump_insn_after_setloc, emit_jump_insn_before_setloc emit_call_insn_after_setloc, emit_call_insn_before_setloc): ... these; (insn_file, insn_line, prologue_locator, epilogue_locator): Declare. * unroll.c (copy_loop_body): Use locators. * function.c (set_insn_locators): New function. (thread_prologue_and_epilogue_insns): Set the locators accordingly. From-SVN: r67637
Diffstat (limited to 'gcc/emit-rtl.c')
-rw-r--r--gcc/emit-rtl.c42
1 files changed, 21 insertions, 21 deletions
diff --git a/gcc/emit-rtl.c b/gcc/emit-rtl.c
index de6e94c..208af57 100644
--- a/gcc/emit-rtl.c
+++ b/gcc/emit-rtl.c
@@ -3586,7 +3586,7 @@ try_split (pat, trial, last)
}
}
- tem = emit_insn_after_scope (seq, trial, INSN_SCOPE (trial));
+ tem = emit_insn_after_setloc (seq, trial, INSN_LOCATOR (trial));
delete_insn (trial);
if (has_barrier)
@@ -3624,7 +3624,7 @@ make_insn_raw (pattern)
INSN_CODE (insn) = -1;
LOG_LINKS (insn) = NULL;
REG_NOTES (insn) = NULL;
- INSN_SCOPE (insn) = NULL;
+ INSN_LOCATOR (insn) = 0;
BLOCK_FOR_INSN (insn) = NULL;
#ifdef ENABLE_RTL_CHECKING
@@ -3658,7 +3658,7 @@ make_jump_insn_raw (pattern)
LOG_LINKS (insn) = NULL;
REG_NOTES (insn) = NULL;
JUMP_LABEL (insn) = NULL;
- INSN_SCOPE (insn) = NULL;
+ INSN_LOCATOR (insn) = 0;
BLOCK_FOR_INSN (insn) = NULL;
return insn;
@@ -3680,7 +3680,7 @@ make_call_insn_raw (pattern)
LOG_LINKS (insn) = NULL;
REG_NOTES (insn) = NULL;
CALL_INSN_FUNCTION_USAGE (insn) = NULL;
- INSN_SCOPE (insn) = NULL;
+ INSN_LOCATOR (insn) = 0;
BLOCK_FOR_INSN (insn) = NULL;
return insn;
@@ -4653,11 +4653,11 @@ emit_line_note_after (file, line, after)
return note;
}
/* Like emit_insn_after, but set INSN_SCOPE according to SCOPE. */
rtx
-emit_insn_after_scope (pattern, after, scope)
+emit_insn_after_setloc (pattern, after, loc)
rtx pattern, after;
- tree scope;
+ int loc;
{
rtx last = emit_insn_after (pattern, after);
@@ -4665,7 +4665,7 @@ emit_insn_after_scope (pattern, after, scope)
while (1)
{
if (active_insn_p (after))
- INSN_SCOPE (after) = scope;
+ INSN_LOCATOR (after) = loc;
if (after == last)
break;
after = NEXT_INSN (after);
@@ -4673,11 +4673,11 @@ emit_insn_after_scope (pattern, after, scope)
return last;
}
/* Like emit_jump_insn_after, but set INSN_SCOPE according to SCOPE. */
rtx
-emit_jump_insn_after_scope (pattern, after, scope)
+emit_jump_insn_after_setloc (pattern, after, loc)
rtx pattern, after;
- tree scope;
+ int loc;
{
rtx last = emit_jump_insn_after (pattern, after);
@@ -4685,7 +4685,7 @@ emit_jump_insn_after_scope (pattern, after, scope)
while (1)
{
if (active_insn_p (after))
- INSN_SCOPE (after) = scope;
+ INSN_LOCATOR (after) = loc;
if (after == last)
break;
after = NEXT_INSN (after);
@@ -4693,11 +4693,11 @@ emit_jump_insn_after_scope (pattern, after, scope)
return last;
}
/* Like emit_call_insn_after, but set INSN_SCOPE according to SCOPE. */
rtx
-emit_call_insn_after_scope (pattern, after, scope)
+emit_call_insn_after_setloc (pattern, after, loc)
rtx pattern, after;
- tree scope;
+ int loc;
{
rtx last = emit_call_insn_after (pattern, after);
@@ -4705,7 +4705,7 @@ emit_call_insn_after_scope (pattern, after, scope)
while (1)
{
if (active_insn_p (after))
- INSN_SCOPE (after) = scope;
+ INSN_LOCATOR (after) = loc;
if (after == last)
break;
after = NEXT_INSN (after);
@@ -4713,11 +4713,11 @@ emit_call_insn_after_scope (pattern, after, scope)
return last;
}
/* Like emit_insn_before, but set INSN_SCOPE according to SCOPE. */
rtx
-emit_insn_before_scope (pattern, before, scope)
+emit_insn_before_setloc (pattern, before, loc)
rtx pattern, before;
- tree scope;
+ int loc;
{
rtx first = PREV_INSN (before);
rtx last = emit_insn_before (pattern, before);
@@ -4726,7 +4726,7 @@ emit_insn_before_scope (pattern, before, scope)
while (1)
{
if (active_insn_p (first))
- INSN_SCOPE (first) = scope;
+ INSN_LOCATOR (first) = loc;
if (first == last)
break;
first = NEXT_INSN (first);
@@ -5798,7 +5798,7 @@ emit_copy_of_insn_after (insn, after)
/* Update LABEL_NUSES. */
mark_jump_label (PATTERN (new), new, 0);
- INSN_SCOPE (new) = INSN_SCOPE (insn);
+ INSN_LOCATOR (new) = INSN_LOCATOR (insn);
/* Copy all REG_NOTES except REG_LABEL since mark_jump_label will
make them. */
@@ -4653,11 +4653,11 @@ emit_line_note_after (file, line, after)
return note;
}
-/* Like emit_insn_after, but set INSN_SCOPE according to SCOPE. */
+/* Like emit_insn_after, but set INSN_LOCATOR according to SCOPE. */
rtx
@@ -4673,11 +4673,11 @@ emit_insn_after_scope (pattern, after, scope)
return last;
}
-/* Like emit_jump_insn_after, but set INSN_SCOPE according to SCOPE. */
+/* Like emit_jump_insn_after, but set INSN_LOCATOR according to SCOPE. */
rtx
@@ -4693,11 +4693,11 @@ emit_jump_insn_after_scope (pattern, after, scope)
return last;
}
-/* Like emit_call_insn_after, but set INSN_SCOPE according to SCOPE. */
+/* Like emit_call_insn_after, but set INSN_LOCATOR according to SCOPE. */
rtx
@@ -4713,11 +4713,11 @@ emit_call_insn_after_scope (pattern, after, scope)
return last;
}
-/* Like emit_insn_before, but set INSN_SCOPE according to SCOPE. */
+/* Like emit_insn_before, but set INSN_LOCATOR according to SCOPE. */
rtx